"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getInputDataFromArgs = exports.validateArgs = void 0;
const util_1 = require("util");
const xml2json_1 = require("xml2json");
const glob_1 = __importDefault(require("glob"));
const fs = __importStar(require("fs"));
const path = __importStar(require("path"));
function printHelp() {
    const packageJson = JSON.parse(fs.readFileSync(path.join(__dirname, '../../package.json')).toString('utf-8'));
    console.log(`Version ${packageJson.version}`);
    console.log('Syntax:    cobertura-merge [options]... [--files=pattern] [package=input...]');
    console.log('');
    console.log('Examples:  cobertura-merge -o output.xml package1=output1.xml package2=output2.xml');
    console.log('           cobertura-merge -o output.xml --files=**/*_coverage.xml');
    console.log('           cobertura-merge -p package1=output1.xml package2=output2.xml');
    console.log('');
    console.log('Options');
    console.log('-o FILE         Specify output file');
    console.log('-p, --print     print coverage report summary');
    process.exit();
}
const KNOWN_ARGS = ['_', 'o', 'p', 'print', 'files'];
function validateArgs(args) {
    // Check for unknown arguments
    const unknownArg = Object.keys(args).find((arg) => KNOWN_ARGS.indexOf(arg) === -1);
    if (unknownArg) {
        console.log(`Unknown argument ${unknownArg}\n`);
        printHelp();
        process.exit(1);
    }
    if ((args._.length < 3 && args.files == undefined) ||
        args.o === true ||
        (0, util_1.isArray)(args.o) ||
        (0, util_1.isString)(args.p) ||
        (0, util_1.isArray)(args.p)) {
        // Input error
        printHelp();
    }
    const inputArgs = args._.slice(2);
    if (args.files == undefined &&
        inputArgs.some((input) => {
            // Check to see if the input is in format package=input
            const matches = input.match(/=/g);
            return !matches || matches.length !== 1 || input.split('=').some((part) => !part.trim());
        })) {
        // Input error
        printHelp();
    }
}
exports.validateArgs = validateArgs;
function getInputDataFromArgs(args) {
    let packages = args._.slice(2);
    // Check if the user wanted to submit files by a glob pattern
    if (args.files != '') {
        // Create an array by appending "package=" before each file found by the glob
        packages = glob_1.default.sync(args.files).map((file, i) => `package${i + 1}=${file}`);
    }
    return packages.map((inputArg, index) => {
        const parts = inputArg.split('=');
        const packageName = parts[0];
        const fileName = parts[1];
        let data;
        try {
            data = JSON.parse((0, xml2json_1.toJson)(fs.readFileSync(fileName, 'utf-8'), {
                arrayNotation: true,
                reversible: true,
            }));
        }
        catch (e) {
            console.log(`Unable to read file ${fileName}`);
            process.exit(1);
        }
        return {
            packageName,
            fileName,
            data,
        };
    });
}
exports.getInputDataFromArgs = getInputDataFromArgs;
//# sourceMappingURL=input.js.map